import { useEffect, useRef, useState } from 'react';
import RecordAudioButton from '@/feature/messenger/components/ui/buttons/RecordAudioButton';
import EmojiButtonMobile from '@/feature/messenger/components/ui/buttons/EmojiButtonMobile';
import useInputMessageStore from '@/feature/messenger/store/chat_store/useInputMessageStore';
import SendMessageButton from '@/feature/messenger/components/ui/buttons/SendMessageButton';
import useConfigChatStore from '@/feature/messenger/store/chat_store/useConfigChatStore';
import useConversationsStore from '@/feature/messenger/store/chat_store/useConversationsStore';
import useMessagesStore from '@/feature/messenger/store/chat_store/useMessagesStore';
import { createMessage } from '@/feature/messenger/services/chat/ChatService';
import OptionsButtonMobile from '@/feature/messenger/components/ui/buttons/OptionsButtonMobile';
import usePermissionChat from '@/feature/messenger/hooks/usePermissionChat';


function TextareaChatMobile() {
    const [rows, setRows] = useState(1);
    const messageInput = useInputMessageStore((state) => state.message);
    const setMessageInput = useInputMessageStore((state) => state.setMessage);
    const id_chatbot = useConfigChatStore(state => state.idChatbot);
    const selectedConversation = useConversationsStore(state => state.selectedConversation);
    const addItemListMessages = useMessagesStore(state => state.actions.addItemListMessages);
    const updateConversation = useConversationsStore(state => state.actions.updateConversation);
    const inputRef = useRef<HTMLTextAreaElement>(null);
    const validateFocus = useMessagesStore(state => state.focus);
    const changeFocus = useMessagesStore(state => state.actions.changeFocus);
    const permisions = usePermissionChat()

    const handleChange = (event: any) => {
        const textareaLineHeight = 24; // La altura de una fila (ajústalo si es necesario)
        const previousRows = event.target.rows;
        event.target.rows = 1; // Reseteamos las filas para calcular las nuevas

        const currentRows = Math.floor(event.target.scrollHeight / textareaLineHeight);

        if (currentRows === previousRows) {
            event.target.rows = currentRows;
        }

        if (currentRows >= 4) {
            event.target.rows = 4; // Limitar a 4 filas
            event.target.scrollTop = event.target.scrollHeight;
        }

        setMessageInput(event.target.value);
        setRows(currentRows < 4 ? currentRows : 4); // Ajustar el valor del estado
    };

    const handleMessagePress = (e: any) => {

        if (e.key === "Enter" || e === "send" || e.type === "click") {
            const container = document.querySelector(".messages");
            if (container) {
                setTimeout(function () {
                    container.scrollBy({ top: 200, behavior: "smooth" });
                }, 310);
            }

            if (messageInput.length > 0) {
                createMessage(id_chatbot, selectedConversation.sesion, messageInput).then((res) => {
                    const response = res.data.data;
                    if (res.success === false) {
                        if (res.data.message === "WordBlockMessage") {
                            setMessageInput("");
                            setRows(1);
                            const words = res.data.words;
                            //toast.error(`El mensaje contiene palabras prohibidas por el sistema (${words})`);
                            return;
                        }
                    }
                    if (response != null) {
                        addItemListMessages(response);
                        const currentSesion = selectedConversation;
                        currentSesion.conversacion = response.conversacion;
                        currentSesion.tipomensaje = response.tipomensaje;
                        currentSesion.fecha = response.fecha_sistema;
                        currentSesion.sinLeer = 0;
                        updateConversation(currentSesion);
                    }
                })
                setRows(1);
                setMessageInput("");
            }
        }
    };

    useEffect(() => {
        if (validateFocus && inputRef.current) {
            inputRef.current.focus();
            changeFocus();
        }
    }, [validateFocus]);

    return (
        <>
            <div className={`flex items-center p-1 bg-gray-200 w-full ${rows === 1 ? 'rounded-full' : 'rounded-2xl'}`}>
                {permisions.envia_emojis && <EmojiButtonMobile />}
                <textarea
                    value={messageInput}
                    rows={rows}
                    placeholder="Mensaje"
                    className="resize-none w-full bg-transparent p-2 focus:outline-none focus:ring-0 min-h-[40px] max-h-[150px] overflow-y-auto"
                    onChange={handleChange}
                />
                <OptionsButtonMobile />
            </div>
            <div className='ml-1'>
                {messageInput.length > 0 ? (<SendMessageButton handleMessagePress={handleMessagePress} />) : <RecordAudioButton />}
            </div>
        </>

    );
}

export default TextareaChatMobile;
